@@ -1,8 +1,9 @@
-// $Id: Configuration.cc 1515 2012-09-26 00:35:10Z peter $
+// $Id: Configuration.cc 1635 2023-03-30 04:16:57Z peter $
 
 /*
-	Copyright (C) 2007, 2008, 2009, 2010, 2011 Jari Häkkinen, Peter Johansson
-	Copyright (C) 2012 Peter Johansson
+	Copyright (C) 2007 Peter Johansson
+	Copyright (C) 2008, 2009, 2010, 2011 Jari Häkkinen, Peter Johansson
+	Copyright (C) 2012, 2023 Peter Johansson
 
 	This file is part of svndigest, http://dev.thep.lu.se/svndigest
 
@@ -374,7 +375,7 @@ namespace svndigest{
 					try {
 						image_format(rhs);
 					}
-					catch (std::runtime_error e) {
+					catch (std::runtime_error& e) {
 						throw Config_error(line,
 															 "unknown format: " + rhs + "\n" + e.what());
 					}
@@ -383,7 +384,7 @@ namespace svndigest{
 					try {
 						image_anchor_format(rhs);
 					}
-					catch (std::runtime_error e) {
+					catch (std::runtime_error& e) {
 						throw Config_error(line,
 															 "unknown format: " + rhs + "\n" + e.what());
 					}
