@@ -1,7 +1,7 @@
 #ifndef _theplu_svndigest_svndigest_visitor_
 #define _theplu_svndigest_svndigest_visitor_
 
-// $Id: SvndigestVisitor.h 1478 2012-05-29 10:17:04Z peter $
+// $Id: SvndigestVisitor.h 1535 2012-10-06 03:33:13Z peter $
 
 /*
 	Copyright (C) 2010, 2012 Peter Johansson
@@ -39,7 +39,7 @@ namespace svndigest{
   class SvndigestVisitor : public NodeVisitor
   {
   public:
-		SvndigestVisitor(bool verbose, bool ignore_cache, bool report);
+		SvndigestVisitor(bool verbose, bool ignore_cache, bool report,bool update);
 
 		/**
 		 */
@@ -57,6 +57,7 @@ namespace svndigest{
 		bool verbose_;
 		bool ignore_cache_;
 		bool report_;
+		bool update_;
 		std::vector<svn_revnum_t> ignore_rev_;
 	};
 }} // end of namespace svndigest and namespace theplu
