@@ -1,7 +1,7 @@
 #!/bin/sh
-# $Id: config_props_test.sh 1373 2011-06-10 23:31:35Z peter $
+# $Id: config_props_test.sh 1532 2012-10-05 01:14:42Z peter $
 #
-# Copyright (C) 2011 Peter Johansson
+# Copyright (C) 2011, 2012 Peter Johansson
 #
 # This file is part of svndigest, http://dev.thep.lu.se/svndigest
 #
@@ -23,7 +23,7 @@
 
 required="repo"
 
-. ./init.sh || exit 1
+. test/init.sh || exit 99
 set -e
 
 # create config file
