@@ -1,9 +1,9 @@
 #!/bin/sh
 
-# $Id: copyright2_test.sh 1515 2012-09-26 00:35:10Z peter $
+# $Id: copyright2_test.sh 1532 2012-10-05 01:14:42Z peter $
 
 # Copyright (C) 2007, 2008 Jari Häkkinen, Peter Johansson
-# Copyright (C) 2009, 2010, 2011 Peter Johansson
+# Copyright (C) 2009, 2010, 2011, 2012 Peter Johansson
 #
 # This file is part of svndigest, http://dev.thep.lu.se/svndigest
 #
@@ -22,7 +22,7 @@
 
 required="repo"
 
-. ./init.sh || exit 1
+. test/init.sh || exit 99
 
 # exit if cmd fails
 set -e
