@@ -1,8 +1,8 @@
 #!/bin/sh
 
-# $Id: link_root_test.sh 1264 2010-11-02 00:46:21Z peter $
+# $Id: link_root_test.sh 1532 2012-10-05 01:14:42Z peter $
 
-# Copyright (C) 2010 Peter Johansson
+# Copyright (C) 2010, 2012 Peter Johansson
 #
 # This file is part of svndigest, http://dev.thep.lu.se/svndigest
 #
@@ -21,7 +21,7 @@
 
 required="repo"
 
-. ./init.sh || exit 1
+. test/init.sh || exit 99
 
 targetdir=output
 rm -rf $targetdir
