@@ -1,9 +1,9 @@
 #!/bin/sh
 
-# $Id: repo_test.sh 1595 2015-08-25 07:57:29Z jari $
+# $Id: repo_test.sh 1598 2015-08-26 15:11:38Z jari $
 
 # Copyright (C) 2007, 2008 Jari Häkkinen, Peter Johansson
-# Copyright (C) 2009, 2010 Peter Johansson
+# Copyright (C) 2009, 2010, 2012 Peter Johansson
 # Copyright (C) 2015 Jari Häkkinen
 #
 # This file is part of svndigest, http://dev.thep.lu.se/svndigest
@@ -23,7 +23,7 @@
 
 required="repo"
 
-. ./init.sh || exit 1
+. test/init.sh || exit 99
 
 targetdir=$abs_builddir/generated_output
 $mkdir_p $targetdir
