@@ -1,7 +1,7 @@
 #!/bin/sh
-# $Id: svncopyright_test.sh 1220 2010-10-13 04:10:52Z peter $
+# $Id: svncopyright_test.sh 1635 2023-03-30 04:16:57Z peter $
 #
-# Copyright (C) 2009, 2010 Peter Johansson
+# Copyright (C) 2009, 2010, 2012, 2023 Peter Johansson
 #
 # This file is part of svndigest, http://dev.thep.lu.se/svndigest
 #
@@ -20,13 +20,13 @@
 
 required=""
 
-. ./init.sh || exit 1
+. test/init.sh || exit 99
 set -e
 
 for opt in --version --help; do
   $SVNCOPYRIGHT $opt > out.tmp 2> error.tmp
-  test -n "`cat out.tmp`" || exit_fail
-  test -z "`cat error.tmp`" || exit_fail
+  test -s out.tmp || exit_fail
+  test -s error.tmp && cat error.tmp >&2 && exit_fail
   rm -f *.tmp
 done
 
