@@ -1,7 +1,7 @@
 #!/bin/sh
-# $Id: svndigest_copy_cache_test.sh 1296 2010-11-14 16:05:33Z peter $
+# $Id: svndigest_copy_cache_test.sh 1532 2012-10-05 01:14:42Z peter $
 #
-# Copyright (C) 2009, 2010 Peter Johansson
+# Copyright (C) 2009, 2010, 2012 Peter Johansson
 #
 # This file is part of svndigest, http://dev.thep.lu.se/svndigest
 #
@@ -19,8 +19,7 @@
 # along with svndigest. If not, see <http://www.gnu.org/licenses/>.
 
 required="repo"
-set -x
-. ./init.sh || exit 1
+. test/init.sh || exit 99
 set -e
 
 for opt in --version --help; do
