@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: svndigest_copy_cache_test2.sh 1515 2012-09-26 00:35:10Z peter $
+# $Id: svndigest_copy_cache_test2.sh 1527 2012-10-02 10:41:54Z peter $
 #
 # Copyright (C) 2012 Peter Johansson
 #
@@ -21,11 +21,10 @@
 # test that svndigest_copy_cache copies cache for svncopyright
 
 required="repo"
-set -x
-. ./init.sh || exit 1
+. test/init.sh || exit 99
 set -e
 
-SVNCOPYRIGHT_run 0 -r $rootdir --no-report
+SVNCOPYRIGHT_run 0 -r $rootdir
 svn revert $rootdir -R
 
 find $rootdir | $GREP svncopyright-cache || exit_fail
