@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# $Id: traverse_test.sh 1495 2012-08-27 04:06:43Z peter $
+# $Id: traverse_test.sh 1525 2012-10-01 06:31:07Z peter $
 
 # Copyright (C) 2012 Peter Johansson
 #
@@ -26,7 +26,7 @@ required="repo"
 
 rm -rf testSubdir/traverse_test.sh.dir
 
-. ./init.sh || exit 99
+. test/init.sh || exit 99
 
 daughter=.svndigest/branches_wc
 
