@@ -1,7 +1,7 @@
 #!/bin/sh
-# $Id: try_help_test.sh 1420 2011-11-02 00:24:53Z peter $
+# $Id: try_help_test.sh 1532 2012-10-05 01:14:42Z peter $
 #
-# Copyright (C) 2011 Peter Johansson
+# Copyright (C) 2011, 2012 Peter Johansson
 #
 # This file is part of svndigest, http://dev.thep.lu.se/svndigest
 #
@@ -20,7 +20,7 @@
 
 required=""
 
-. ./init.sh || exit 99
+. test/init.sh || exit 99
 set -e
 
 SVNDIGEST_run 1 nonsense
