@@ -1,7 +1,7 @@
-// $Id: split.cc 2434 2011-03-08 16:52:23Z peter $
+// $Id: split.cc 2881 2012-11-18 01:28:05Z peter $
 
 /*
-	Copyright (C) 2010 Peter Johansson
+	Copyright (C) 2010, 2012 Peter Johansson
 
 	This file is part of the yat library, http://dev.thep.lu.se/yat
 
@@ -19,6 +19,8 @@
 	along with yat. If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <config.h>
+
 #include "split.h"
 
 #include <string>
@@ -28,7 +30,14 @@ namespace theplu {
 namespace yat {
 namespace utility {
 
-	void split(std::vector<std::string>& vec, const std::string& str, char delim)
+namespace detail {
+
+	/*
+		implementation of split functions is declared in private namespace
+		and only available in this file.
+	 */
+	template<typename T>
+	void split(std::vector<std::string>& vec, const std::string& str, T delim)
 	{
 		size_t pos=0;
 		while (true) {
@@ -39,5 +48,19 @@ namespace utility {
 			pos = end+1;
 		}
 	}
+} // end of namespace detail
+
+
+	void split(std::vector<std::string>& vec, const std::string& str, char delim)
+	{
+		detail::split(vec, str, delim);
+	}
+
+
+	void split(std::vector<std::string>& vec, const std::string& str,
+						 const std::string& delim)
+	{
+		detail::split(vec, str, delim);
+	}
 
 }}} // of namespace utility, yat, and theplu
