@@ -1,10 +1,10 @@
 #ifndef _theplu_yat_utility_split_
-#define _theplu_yat_utility_split_ 
+#define _theplu_yat_utility_split_
 
-// $Id: split.h 2434 2011-03-08 16:52:23Z peter $
+// $Id: split.h 2898 2012-12-12 05:13:02Z peter $
 
 /*
-	Copyright (C) 2010 Peter Johansson
+	Copyright (C) 2010, 2012 Peter Johansson
 
 	This file is part of the yat library, http://dev.thep.lu.se/yat
 
@@ -35,14 +35,28 @@ namespace utility {
 		 Split \a str with respect to \a delim and place result in \a
 		 result. If \a str contains N \a delim, the resulting \a result
 		 will hold N+1 elements (given that it was empty to start
-		 with). If first or loast character in \a str is \a delim,
+		 with). If first or last character in \a str is \a delim,
 		 corresponding element in \a result will be empty string ("").
 
 		 \since New in yat 0.7
 	 */
-	void split(std::vector<std::string>& result, const std::string& str, 
+	void split(std::vector<std::string>& result, const std::string& str,
 						 char delim);
 
+	/**
+		 \brief split a string into substrings
+
+		 Same as
+		 void split(std::vector<std::string>&, const std::string&,char delim);
+		 but split if character matches any in delims, i.e.,
+		 split(vec,"split,me;please", ",;") will be split into "split",
+		 "me", and "please".
+
+		 \since New in yat 0.10
+	 */
+	void split(std::vector<std::string>& result, const std::string& str,
+						 const std::string& delim);
+
 }}} // of namespace utility, yat, and theplu
 
 #endif
