@@ -1,7 +1,7 @@
 #ifndef _theplu_yat_utility_stl_utility_
 #define _theplu_yat_utility_stl_utility_
 
-// $Id: stl_utility.h 1498 2012-08-27 06:34:11Z peter $
+// $Id: stl_utility.h 1640 2023-04-14 23:55:55Z peter $
 
 /*
 	Copyright (C) 2004 Jari Häkkinen
@@ -373,8 +373,11 @@ namespace utility {
 		 \since New in yat 0.7
 	 */
 	template<typename T>
-	struct Identity : public std::unary_function<T, T>
+	struct Identity
 	{
+		typedef T argument_type;
+		typedef T result_type;
+
 		/// \return \a arg
 		T operator()(T arg) const { return arg; }
 	};
@@ -437,6 +440,28 @@ namespace utility {
 	}
 
 
+	/**
+		 Create a map mapping from values in range [first, last) to the
+		 distance from first.
+
+		 Post-condition: m[first[i]] == i (for all i that correspond to a
+		 unique element). For non-unique element behaviour is undefined.
+
+		 Requirement: InputIterator's value type is assignable to Key
+
+		 \since New in yat 0.10
+	 */
+	template<typename InputIterator, typename Key, typename Comp>
+	void inverse(InputIterator first, InputIterator last,
+							 std::map<Key, size_t, Comp >& m)
+	{
+		BOOST_CONCEPT_ASSERT((boost::InputIterator<InputIterator>));
+		BOOST_CONCEPT_ASSERT((boost::Convertible<typename std::iterator_traits<InputIterator>::value_type, Key>));
+		m.clear();
+		for (size_t i=0; first!=last; ++i, ++first)
+			m[*first] = i;
+	}
+
 	/**
 		 \brief Functor that behaves like std::less with the exception
 		 that it treates NaN as a number larger than infinity.
